@@ -1,6 +1,15 @@
 from xl_docx.compiler.processors.component import ComponentProcessor
 
 
+
+def test_new():
+    processor = ComponentProcessor()
+    xml = '<xl-check condition="2>1">content</xl-check>'
+    result = processor.compile(xml)
+    expected = '($ if 2>1 $)content($ endif $)'
+    assert result == expected
+
+
 def test_basic_component():
     """Test basic component functionality"""
     # Process XML
